package net.zhypower.sample;

import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.ComponentName;
import android.content.Intent;
import android.text.InputType;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.Spinner;
import android.widget.TextView;

/**
 * @author Wenlai Zhao
 */
public class RegisterActivity extends Activity {

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.register);
        
        Intent intent = getIntent();
        UserParcelable user = intent.getParcelableExtra("userinfo");
        if  (user != null) {
        	doInit(user);
        }
        
        final EditText pwd_edit = (EditText)findViewById(R.id.pwd);
        final EditText pwdconfirm_edit = (EditText)findViewById(R.id.pwd_confirm);
        final int defaultType = pwd_edit.getInputType();

        //パスワード表示のチェックボックス
        CheckBox display_pwd = (CheckBox)findViewById(R.id.display_password);
        display_pwd.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
				if (isChecked) {
					pwd_edit.setInputType(defaultType | InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD);
					pwdconfirm_edit.setInputType(defaultType | InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD);
				} else {
					pwd_edit.setInputType(defaultType |InputType.TYPE_TEXT_VARIATION_PASSWORD);
					pwdconfirm_edit.setInputType(defaultType |InputType.TYPE_TEXT_VARIATION_PASSWORD);
				}
			}
		});
        
        //登録ボタン
       final Button btn = (Button)findViewById(R.id.register);
        btn.setOnClickListener(new View.OnClickListener() {
			
			@Override
			public void onClick(View view) {
				doRegister();
			}
		});
        
        
        //リセットボタン
       Button btn2 = (Button)findViewById(R.id.reset);
        btn2.setOnClickListener(new View.OnClickListener() {
			
			@Override
			public void onClick(View view) {
				doInit(null);
			}
		});
        
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.register, menu);
        return true;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (item.getItemId() == R.id.version) {
            AlertDialog.Builder builder = new AlertDialog.Builder(this);
            builder.setTitle("info").setMessage(getString(R.string.version)).create().show();
            return true;
        } else {
            return super.onOptionsItemSelected(item);
        }
    }
    
    /**
     * 登録処理を行う
     */
    private void doRegister() {
    	
    	String userid = trimToEmpty(((EditText)findViewById(R.id.userid)).getText().toString());
    	String pwd = trimToEmpty(((EditText)findViewById(R.id.pwd)).getText().toString());
    	String pwd_confirm = trimToEmpty(((EditText)findViewById(R.id.pwd_confirm)).getText().toString());
    	
    	if ("".equals(userid)) {
    		showErrorMsg(R.string.error_msg_userid_null);
    		return ;
    	}
    	
    	if ("".equals(pwd)) {
    		showErrorMsg(R.string.error_msg_pwd_null);
    		return ;
    	}
    	
    	if (!pwd.equals(pwd_confirm)) {
    		showErrorMsg(R.string.error_msg_pwd_unsame);
    		return ;
    	}
    	
    	String sex = trimToEmpty(((RadioButton)findViewById(((RadioGroup)findViewById(R.id.sex)).getCheckedRadioButtonId())).getText().toString());
    	Spinner spinner1 = (Spinner)findViewById(R.id.age);
    	String age = (String)spinner1.getSelectedItem();
    	
    	UserParcelable userInfo = new UserParcelable();
    	userInfo.setUserid(userid);
    	userInfo.setPassword(pwd);
    	userInfo.setSex(sex);
    	userInfo.setAge(age);
    	
    	Intent intent = new Intent();
    	intent.setComponent(new ComponentName(this,RegisterConfirmActivity.class));
    	intent.putExtra("userinfo", userInfo);
    	startActivity(intent);
    	finish();
    }
    
	/**
	 * 画面表示を初期化。<br>
	 * 指定したユーザーモデルがnullでない場合、モデルの内容で画面表示化を初期化する
	 * 
	 * @param user
	 */
    private void doInit(UserParcelable user) {
    	TextView msgView = (TextView)findViewById(R.id.label_msg);
    	msgView.setVisibility(View.GONE);
    	
    	String userid = "";
    	String pwd = "";
    	String pwd_confirm = "";
    	int selectedSex = R.id.sex_man;
    	int selectedAgePos = 0;
    	
    	if (user != null) {
    		userid = user.getUserid();
    		pwd = user.getPassword();
    		pwd_confirm = user.getPassword();
    		if (user.getSex().equals(getString(R.string.label_sex_man))) {
    			selectedSex = R.id.sex_man;
    		} else {
    			selectedSex = R.id.sex_woman;
    		}
    		String age = user.getAge();
    		String[] ages = getResources().getStringArray(R.array.ages);
    		int i = 0;
    		for(String _age:ages) {
    			if (_age.equals(age)) {
    				selectedAgePos = i;
    				break;
    			}
    			i++;
    		}
    	}
    	((EditText)findViewById(R.id.userid)).setText(userid);
    	((EditText)findViewById(R.id.pwd)).setText(pwd);
    	((EditText)findViewById(R.id.pwd_confirm)).setText(pwd_confirm);
    	((CheckBox)findViewById(R.id.display_password)).setChecked(false);
    	((RadioButton)findViewById(selectedSex)).setChecked(true);
    	Spinner ageSpinner = (Spinner)findViewById(R.id.age);

    	ageSpinner.setSelection(selectedAgePos);
    }
    
    private void showErrorMsg (int resid) {
    	TextView msgView = (TextView)findViewById(R.id.label_msg);
    	msgView.setText(resid);
    	msgView.setVisibility(View.VISIBLE);
    }
    
    private String trimToEmpty(String str) {
    	return str == null ? "":str.trim();
    }
}
