package net.zhypower.ntsample.test;

import junit.framework.Test;
import junit.framework.TestSuite;
import net.zhypower.sample.CounterActivity;
import android.app.Instrumentation;
import android.content.Intent;
import android.test.ActivityUnitTestCase;

/**
 * ActivityUnitTestCaseを利用するサンプル。<br>
 * ActivityUnitTestCaseは下記のテストに向いている。<br>
 * データモデル、内部のビジネスロジック、ライフサイクル
 * 
 * @author Wenlai ZHAO
 *
 */
public class CounterUnitTest extends
		ActivityUnitTestCase<CounterActivity> {

	public CounterUnitTest(Class<CounterActivity> activityClass) {
		super(activityClass);
	}

	public CounterUnitTest() {
		this(CounterActivity.class);
	}

	public CounterUnitTest(String name) {
		this(CounterActivity.class);
		setName(name);
	}

	public static Test suite() {
		TestSuite suite = new TestSuite("test");
		suite.addTest(new CounterUnitTest("test_lifecycle"));
		return suite;
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void test_lifecycle() {
	    Intent intent = new Intent(Intent.ACTION_MAIN);
	    startActivity(intent,null,null);
	    
	    final CounterActivity counterActivity = getActivity();

		final Instrumentation mInst = getInstrumentation();

		int curCounter = counterActivity.getCounter();
		
		// onCreate()のみ呼び出されているため、counter=0
		assertEquals(0, curCounter);

		counterActivity.runOnUiThread(new Runnable() {
			@Override
			public void run() {
				mInst.callActivityOnResume(counterActivity);
			}
		});
		mInst.waitForIdleSync();

		// onResume()で、counterがもう一回加算されたため、counter=1
		curCounter = counterActivity.getCounter();
		assertEquals(1, curCounter);

		counterActivity.runOnUiThread(new Runnable() {
			@Override
			public void run() {
				mInst.callActivityOnPause(counterActivity);
			}
		});
		
		mInst.waitForIdleSync();
		
        // onPause()で、counterがもう一回加算されたため、counter=2
		curCounter = counterActivity.getCounter();
		assertEquals(2, curCounter);
		
		counterActivity.finish();
		mInst.waitForIdleSync();
		
		counterActivity.runOnUiThread(new Runnable() {
			@Override
			public void run() {
				mInst.callActivityOnResume(counterActivity);
			}
		});

        // onResume()で、counterがもう一回加算されたため、counter=3
        curCounter = counterActivity.getCounter();
        assertEquals(3, curCounter);
	}
}
