package net.zhypower.ntsample.test;

import net.zhypower.sample.R;
import net.zhypower.sample.RegisterActivity;
import net.zhypower.sample.RegisterConfirmActivity;
import junit.framework.Test;
import junit.framework.TestSuite;
import android.app.Activity;
import android.app.Instrumentation;
import android.content.ComponentName;
import android.content.Intent;
import android.test.InstrumentationTestCase;
import android.test.TouchUtils;
import android.view.KeyEvent;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.Spinner;
import android.widget.TextView;

/**
 * 登録システムの結合テスト
 * 
 * @author Wenlai ZHAO
 * 
 */
public class RegisterTest extends InstrumentationTestCase {

    public static Test suite() {
        TestSuite suite = new TestSuite("test");
        suite.addTest(new RegisterTest("test_register"));
        return suite;
    }

    public RegisterTest(String name) {
        this.setName(name);
    }

    @Override
    protected void setUp() throws Exception {
        super.setUp();
    }

    @Override
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    /**
     * 結合テストのシナリオテストとして、下記で実施しています。<br>
     * a)「登録情報入力」画面を起動する<br>
     * b)下記のユーザー情報を入力する<br>
     * ユーザーID/パスワード/パスワード確認を入力する<br>
     * パスワード表示のチェックボックスをONに、性別を「女」に、年齢を「40世代」に変更する<br>
     * c)「登録」ボタンを押して「登録情報確認」画面に遷移する<br>
     * d）「登録情報確認」画面の表示は「登録情報入力」画面の入力内容と一致しているかどうかを確認する<br>
     */
    public void test_register() {
        Instrumentation mInst = getInstrumentation();
        // 「登録情報入力」画面のＡｃｔｉｖｉｔｙのモニタを追加する
        Instrumentation.ActivityMonitor monitor = mInst.addMonitor(
                RegisterActivity.class.getName(), null, false);

        Intent intent = new Intent();
        intent.setAction(Intent.ACTION_MAIN);
        intent.addCategory(Intent.CATEGORY_DEFAULT);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        intent.setComponent(new ComponentName(mInst.getTargetContext(),
                RegisterActivity.class.getName()));
        mInst.startActivitySync(intent);

        // モニタがヒットするまで一秒を待つ
        Activity registerActivity = mInst.waitForMonitorWithTimeout(monitor,
                1000);
        mInst.removeMonitor(monitor);

        assertNotNull(registerActivity);

        final EditText useridElem = (EditText) registerActivity
                .findViewById(R.id.userid);
        final EditText pwdElem = (EditText) registerActivity
                .findViewById(R.id.pwd);
        final EditText pwdCfmElem = (EditText) registerActivity
                .findViewById(R.id.pwd_confirm);
        final CheckBox dspPwdElem = (CheckBox) registerActivity
                .findViewById(R.id.display_password);
        final RadioButton womanElem = (RadioButton) registerActivity
                .findViewById(R.id.sex_woman);
        final Spinner ageElem = (Spinner) registerActivity
                .findViewById(R.id.age);
        Button registerElem = (Button) registerActivity
                .findViewById(R.id.register);

        // 入力を行う
        registerActivity.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                // ユーザーＩＤを入力
                useridElem.setText("tanaka");
                // パスワードを入力
                pwdElem.setText("123456");
                // パスワード確認を入力する
                pwdCfmElem.setText("123456");
            }
        });
        mInst.waitForIdleSync();
        // パスワード表示のチェックボックスをONにする
        TouchUtils.clickView(RegisterTest.this, dspPwdElem);
        // 性別は「女」を選択する
        TouchUtils.clickView(RegisterTest.this, womanElem);
        // 年齢を選択
        TouchUtils.clickView(RegisterTest.this, ageElem);

        // 四番目の「40世代」を選択する
        for (int i = 0; i < 4; i++) {
            sendKeys(KeyEvent.KEYCODE_DPAD_DOWN);
        }
        sendKeys(KeyEvent.KEYCODE_ENTER);

        assertEquals("tanaka", useridElem.getText().toString());
        assertTrue(dspPwdElem.isChecked());

        // 「登録情報確認」画面のActivityのモニタを追加する
        monitor = getInstrumentation().addMonitor(
                RegisterConfirmActivity.class.getName(), null, false);

        // 登録ボタンを押して画面を遷移する
        TouchUtils.clickView(RegisterTest.this, registerElem);
        Activity confirmAct = getInstrumentation().waitForMonitorWithTimeout(
                monitor, 2000);
        assertNotNull(confirmAct);
        assertEquals(RegisterConfirmActivity.class.getName(), confirmAct
                .getComponentName().getClassName());

        // 「登録情報確認」画面の表示を確認する
        // タイトルを確認する
        assertEquals("登録情報確認", confirmAct.getTitle().toString());
        String userid = ((TextView) confirmAct.findViewById(R.id.userid))
                .getText().toString();
        String pwd = ((TextView) confirmAct.findViewById(R.id.pwd)).getText()
                .toString();
        String sex = ((TextView) confirmAct.findViewById(R.id.sex)).getText()
                .toString();
        String age = ((TextView) confirmAct.findViewById(R.id.age)).getText()
                .toString();

        assertEquals("tanaka", userid);
        assertEquals("123456", pwd);
        assertEquals("女", sex);
        assertEquals("40世代", age);
    }
}
